#  tests for netcdf4-1.6.2-py310h6d89c78_0 (this is a generated file);
print('===== testing package: netcdf4-1.6.2-py310h6d89c78_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import netCDF4
import os
import tempfile
import urllib.request

# libnetcdf needs to be able to write a cookie file to $TEMP so set it to $PREFIX
os.environ['TEMP'] = os.environ['PREFIX']

# (tkoch) we don't have OPeNDAP support enabled, which is needed for working
#         with URLs directly.
#
#url = 'http://geoport-dev.whoi.edu/thredds/dodsC/estofs/atlantic'
#with netCDF4.Dataset(url) as nc:
#    # Compiled with cython.
#    assert nc.filepath() == url

url = 'https://geoport.whoi.edu/thredds/fileServer/usgs/vault0/models/tides/vdatum_gulf_of_maine/adcirc54_38_orig.nc'

with tempfile.TemporaryDirectory() as tmpdir:
    ncfile = os.path.join(tmpdir, url.rsplit('/', 1)[-1])

    with open(ncfile, "wb+") as f, urllib.request.urlopen(url) as response:
        for chunk in iter(lambda: response.read(8192), b""):
            f.write(chunk)

    with netCDF4.Dataset(ncfile) as nc:
        nc['tidenames'][:]
#  --- run_test.py (end) ---

print('===== netcdf4-1.6.2-py310h6d89c78_0 OK =====');
print("import: 'netCDF4'")
import netCDF4

print("import: 'cftime'")
import cftime




# init for netCDF4. package
# Docstring comes from extension module _netCDF4.
from ._netCDF4 import *
# Need explicit imports for names beginning with underscores
from ._netCDF4 import __doc__
from ._netCDF4 import (__version__, __netcdf4libversion__, __hdf5libversion__,
                       __has_rename_grp__, __has_nc_inq_path__,
                       __has_nc_inq_format_extended__, __has_nc_open_mem__,
                       __has_nc_create_mem__, __has_cdf5_format__,
                       __has_parallel4_support__, __has_pnetcdf_support__,
                       __has_quantization_support__, __has_zstandard_support__,
                       __has_bzip2_support__, __has_blosc_support__, __has_szip_support__,
                       __has_set_alignment__)
import os
__all__ =\
['Dataset','Variable','Dimension','Group','MFDataset','MFTime','CompoundType','VLType','date2num','num2date','date2index','stringtochar','chartostring','stringtoarr','getlibversion','EnumType','get_chunk_cache','set_chunk_cache','set_alignment','get_alignment']
# if HDF5_PLUGIN_PATH not set, point to package path if plugins live there
pluginpath = os.path.join(__path__[0],'plugins')
if 'HDF5_PLUGIN_PATH' not in os.environ and\
    (os.path.exists(os.path.join(pluginpath,'lib__nczhdf5filters.so')) or\
     os.path.exists(os.path.join(pluginpath,'lib__nczhdf5filters.dylib'))):
    os.environ['HDF5_PLUGIN_PATH']=pluginpath
